@@ -340,8 +340,9 @@ predict.merMod <- function(object, newdata=NULL, newparams=NULL,
             ## Use original model 'X' matrix and offset
             fit.na.action <- attr(object@frame,"na.action")  ## original NA action
             ## orig. offset: will be zero if there are no matches ...
-            offset <- rowSums(object@frame[grepl("offset\\(.*\\)",
-                                                 names(object@frame))])
+            offset <- model.offset(model.frame(object))
+            if (is.null(offset)) offset <- 0
+            
         } else {  ## new data specified
             ## evaluate new fixed effect
             RHS <- formula(substitute(~R,
@@ -370,9 +371,10 @@ predict.merMod <- function(object, newdata=NULL, newparams=NULL,
             }
             ## FIXME?: simplify(no need for 'mfnew'): can this be different from 'na.action'?
             fit.na.action <- attr(mfnew,"na.action")
-        }
-	if(is.numeric(X.col.dropped) && length(X.col.dropped) > 0)
+            ## only need to drop if new data specified ...
+            if(is.numeric(X.col.dropped) && length(X.col.dropped) > 0)
 	    X <- X[, -X.col.dropped, drop=FALSE]
+        }
         pred <- drop(X %*% fixef(object))
         ## FIXME:: need to unname()  ?
         ## FIXME: is this redundant??
@@ -434,6 +436,11 @@ simulate.merMod <- function(object, nsim = 1, seed = NULL, use.u = FALSE,
                          offset=NULL,
                          allow.new.levels=FALSE, na.action=na.pass, ...) {
 
+    if (is.null(weights)) {
+        if (is.null(newdata))
+            weights <- weights(object)
+        else weights <- rep(1,nrow(newdata))
+    }
     if (missing(object)) {
         if (is.null(formula) || is.null(newdata) || is.null(newparams)) {
             stop("if ",sQuote("object")," is missing, must specify all of ",
@@ -441,7 +448,6 @@ simulate.merMod <- function(object, nsim = 1, seed = NULL, use.u = FALSE,
                  sQuote("newparams"))
         }
 
-        if (is.null(weights)) weights <- rep(1,nrow(newdata))
         ## construct fake-fitted object from data, params
         ## copied from glm(): DRY; this all stems from the
         ## original sin of handling family=gaussian as a special
@@ -530,8 +536,6 @@ simulate.merMod <- function(object, nsim = 1, seed = NULL, use.u = FALSE,
         } else substitute(OP(X,Y), list(X=x,OP=op,Y=y))
     }
 
-    ## this fails for complex RE terms such as (1|f/g):
-    ## findbars() is longer than the number of RE forms
     compReForm <- reOnly(formula(object))
     if (!noReForm(re.form)) {
         rr <- reOnly(re.form)[[2]] ## expand RE and strip ~
@@ -576,7 +580,8 @@ simulate.merMod <- function(object, nsim = 1, seed = NULL, use.u = FALSE,
             stop("simulation not implemented for family",
                  family$family)
         ## don't rely on automatic recycling
-        val <- sfun(object, nsim=1, ftd = rep_len(musim, n*nsim))
+        val <- sfun(object, nsim=1, ftd = rep_len(musim, n*nsim),
+                    wts = weights)
         ## split results into nsims: need special case for binomial matrix/factor responses
         if (family$family=="binomial" && is.matrix(r <- model.response(object@frame))) {
             lapply(split(val[[1]], gl(nsim, n, 2 * nsim * n)), matrix,
@@ -616,11 +621,14 @@ simulate.merMod <- function(object, nsim = 1, seed = NULL, use.u = FALSE,
         }
     }
 
+    nafun <- function(x) { x[] <- apply(x,
+                                        2L,
+                                        napredict,
+                                        omit = fit.na.action); x }
     val <- if (is.matrix(val[[1]])) {
 	## have to handle binomial response matrices differently --
 	## fill in NAs as appropriate in *both* columns
-	structure(lapply(val, function(x) apply(x, 2L, napredict,
-						omit = fit.na.action)),
+	structure(lapply(val, nafun),
 		  ## have to put this back into a (weird) data frame again,
 		  ## carefully (should do the napredict stuff
 		  ## earlier, so we don't have to redo this transformation!)
@@ -660,24 +668,26 @@ simulate.merMod <- function(object, nsim = 1, seed = NULL, use.u = FALSE,
 ##     from the fitted objects -- this allows simulation with new
 ##     parameters or new predictor variables
 ## (2) modifying wts from object$prior.weights to weights(object)
+## (3) adding wts as an argument
 ##
 ##
 ## these can be incorporated by overwriting the simulate()
 ## components, or calling them
 ##
-gaussian_simfun <- function(object, nsim, ftd=fitted(object)) {
-    wts <- weights(object)
+gaussian_simfun <- function(object, nsim, ftd=fitted(object),
+                            wts=weights(object)) {
+    
     if (any(wts != 1)) warning("ignoring prior weights")
     rnorm(nsim*length(ftd), ftd, sd=sigma(object))
 }
 
-binomial_simfun <- function(object, nsim, ftd=fitted(object)) {
+binomial_simfun <- function(object, nsim, ftd=fitted(object),
+                            wts=weights(object)) {
     n <- length(ftd)
     ntot <- n*nsim
-    wts <- weights(object)
     if (any(wts %% 1 != 0))
         stop("cannot simulate from non-integer prior.weights")
-    ## Try to fathom out if the original data were
+    ## Try to figure out if the original data were
     ## proportions, a factor or a two-column matrix
     if (!is.null(m <- model.frame(object))) {
         y <- model.response(m)
@@ -700,7 +710,8 @@ binomial_simfun <- function(object, nsim, ftd=fitted(object)) {
     } else rbinom(ntot, size = wts, prob = ftd)/wts
 }
 
-poisson_simfun <- function(object, nsim, ftd=fitted(object)) {
+poisson_simfun <- function(object, nsim, ftd=fitted(object),
+                           wts=weights(object)) {
         ## A Poisson GLM has dispersion fixed at 1, so prior weights
         ## do not have a simple unambiguous interpretation:
         ## they might be frequency weights or indicate averages.
@@ -712,8 +723,8 @@ poisson_simfun <- function(object, nsim, ftd=fitted(object)) {
 
 ##' FIXME: need a gamma.shape.merMod method in order for this to work.
 ##'        (see initial shot at gamma.shape.merMod below)
-Gamma_simfun <- function(object, nsim, ftd=fitted(object)) {
-    wts <- weights(object)
+Gamma_simfun <- function(object, nsim, ftd=fitted(object),
+                         wts=weights(object)) {
     if (any(wts != 1)) message("using weights as shape parameters")
     ## ftd <- fitted(object)
     shape <- MASS::gamma.shape(object)$alpha * wts
@@ -753,9 +764,10 @@ gamma.shape.merMod <- function(object, ...) {
 ## (triggers a NOTE in R CMD check)
 ## modified from @aosmith16 GH contribution
 
-negative.binomial_simfun <- function (object, nsim, ftd = fitted(object))
+negative.binomial_simfun <- function (object, nsim, ftd = fitted(object),
+                                          wts=weights(object))
 {
-    wts <- weights(object)
+
     if (any(wts != 1))
         warning("ignoring prior weights")
     theta <- getNBdisp(object)
